@@ -17,11 +17,21 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='theme',
             name='logo_color',
-            field=colorfield.fields.ColorField(blank=True, default='#FFFFFF', help_text='#FFFFFF', max_length=10, verbose_name='color'),
+            field=colorfield.fields.ColorField(
+                blank=True,
+                default='#FFFFFF',
+                help_text='#FFFFFF',
+                max_length=10,
+                verbose_name='color'),
         ),
         migrations.AlterField(
             model_name='theme',
             name='title_color',
-            field=colorfield.fields.ColorField(blank=True, default='#F5DD5D', help_text='#F5DD5D', max_length=10, verbose_name='color'),
+            field=colorfield.fields.ColorField(
+                blank=True,
+                default='#F5DD5D',
+                help_text='#F5DD5D',
+                max_length=10,
+                verbose_name='color'),
         ),
     ]
