@@ -15,6 +15,10 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='theme',
             name='name',
-            field=models.CharField(default='Django', max_length=50, unique=True, verbose_name='name'),
+            field=models.CharField(
+                default='Django',
+                max_length=50,
+                unique=True,
+                verbose_name='name'),
         ),
     ]
